@@ -137,8 +137,13 @@ fn run(cli_args: CliArgs, global_config: &GlobalConfig) {
     // ensure profile env was not overridden
     profile::set(&normalized_profile_name);
 
-    if cli_args.list_all_steps {
-        cli_commands::list_steps::run(&config, &cli_args.output_format, &cli_args.output_file);
+    if cli_args.list_all_steps || cli_args.list_category_steps.is_some() {
+        cli_commands::list_steps::run(
+            &config,
+            &cli_args.output_format,
+            &cli_args.output_file,
+            cli_args.list_category_steps,
+        );
     } else if cli_args.diff_execution_plan {
         let default_config = descriptor::load_internal_descriptors(true, experimental, None);
         cli_commands::diff_steps::run(&default_config, &config, &task, &cli_args);
@@ -239,6 +244,11 @@ fn run_for_args(
         .unwrap_or(DEFAULT_OUTPUT_FORMAT)
         .to_string();
 
+    cli_args.list_category_steps = match cmd_matches.value_of("list-category-steps") {
+        Some(value) => Some(value.to_string()),
+        None => None,
+    };
+
     cli_args.output_file = match cmd_matches.value_of("output_file") {
         Some(value) => Some(value.to_string()),
         None => None,
@@ -441,6 +451,12 @@ fn create_cli<'a, 'b>(
                 .long("--list-all-steps")
                 .help("Lists all known steps"),
         )
+        .arg(
+            Arg::with_name("list-category-steps")
+                .long("--list-category-steps")
+                .value_name("CATEGORY")
+                .help("List steps for a given category"),
+        )
         .arg(
             Arg::with_name("diff-steps")
                 .long("--diff-steps")
